/*
For information on this software or to report bugs please visit http://www.ranton.org
or email ranton.org

Copyright (c) 2002, Richard Neal Anton
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

*	Redistributions of source code must retain the above copyright notice, this list
	of conditions and the following disclaimer. 

*	Redistributions in binary form must reproduce the above copyright notice, this list
	of conditions and the following disclaimer in the documentation and/or other materials
	provided with the distribution. 

*	The name of the copyright holder may not be used to endorse or promote products 
	derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef __BUFFER__
#define __BUFFER__

#include <sys/time.h>

#include "soundio.h"

// this is the number of seconds of sound we try to buffer
#define kBufferSeconds 1

// this is the structure for a sound fragment
struct SoundFrag_struct {
	long long fragNum; // number of this fragment.
	unsigned char *fragMem; // fragment sound data.
	struct SoundFrag_struct *last,*next; // last,next fragments
};

typedef struct SoundFrag_struct SoundFrag;
// this allocates and sets up the audio buffering stuff.
int setup_audio_buffers(void);

// this frees a list of sound fragments
void free_frag_list(SoundFrag *head);

// this frees the audio buffers
void free_audio_buffers(void);

// this reads a new sound fragment, discarding the oldest
// buffered one if necessary to make room, and puts it on
// the tail of the gFragHead/gFragTail list
int read_fragment(void);

// this writes a sound fragment(the oldest one), then takes it out
// of the used list and puts it in the free list
int write_fragment(void);

// fragment and buffering stuff for the audio
extern struct timeval gStartTime; // time the server started at.
extern long long gCurrFrag;

extern int gFragSize; // size of a sound fragment.
extern int gNumFrags; // number of fragments we keep for buffering

// list of fragments buffered
extern SoundFrag *gFragHead, *gFragTail; 
extern SoundFrag *gFragFree; // list of free fragments

// this is the sound format we are operating in.
extern SoundFormat gSoundFormat;

extern char *gSoundDevName; // default sound device
extern int gSoundDev; // the sound device's fd


#endif
