/*
For information on this software or to report bugs please visit http://www.ranton.org
or email ranton.org

Copyright (c) 2002, Richard Neal Anton
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

*	Redistributions of source code must retain the above copyright notice, this list
	of conditions and the following disclaimer. 

*	Redistributions in binary form must reproduce the above copyright notice, this list
	of conditions and the following disclaimer in the documentation and/or other materials
	provided with the distribution. 

*	The name of the copyright holder may not be used to endorse or promote products 
	derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef __SOUND_IO__
#define __SOUND_IO__

// #include <linux/soundcard.h>
#include <soundcard.h>

/******************* structures ****************************/
typedef struct {
	int format; // format of sample, constants from soundcard.h
	int channels; // number of channels
	int speed; // rate of sampling(Hz)
} SoundFormat;


/****************** prototypes ****************************/
// this returns the deviance of one number from the other
// as a percent of the first number.
// NOTE: this doesn't work if either parameter is negative.
int PercentDeviance( int requested, int actual );

// this returns the bandwidth used, in bytes per second
// of a sound format
int GetSoundBandwidth( SoundFormat *format );

// these sets # of channels, sample format, and sampling speed,
// the actual settings it managed to come up with are returned
// in ioSoundFormat, which is also the input parameters.
// inability to get a desired format,# of channles, or speed
// does not cause this to return an error value.
// if it does return an error, the contents of ioSoundFormat
// are undefined and mostly meaningless.
int SetSoundFormat( int inSound_fd, SoundFormat *ioSoundFormat );

// this gets the fragment size.
int GetFragmentSize( int inSound_fd, int *outFragSize );

#ifdef __linux__
#define DEFAULT_DEV "/dev/dsp"
#else
#define DEFAULT_DEV "/dev/audio"
#endif

#endif

